@@ -1,18 +1,7 @@
 /*
-  Copyright (c) 2009-2018 Montel Laurent <montel@kde.org>
+  SPDX-FileCopyrightText: 2009-2020 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #ifndef MAILCOMMON_FOLDERCOLLECTIONMONITOR_H
@@ -36,6 +25,10 @@ class Session;
 
 namespace MailCommon {
 class FolderCollectionMonitorPrivate;
+/**
+ * @brief The FolderCollectionMonitor class
+ * @author Laurent Montel <montel@kde.org>
+ */
 class MAILCOMMON_EXPORT FolderCollectionMonitor : public QObject
 {
     Q_OBJECT
@@ -44,7 +37,7 @@ public:
     explicit FolderCollectionMonitor(Akonadi::Session *session, QObject *parent = nullptr);
     ~FolderCollectionMonitor();
 
-    Akonadi::ChangeRecorder *monitor() const;
+    Q_REQUIRED_RESULT Akonadi::ChangeRecorder *monitor() const;
     void expireAllFolders(bool immediate, QAbstractItemModel *collectionModel);
     void expunge(const Akonadi::Collection &, bool sync = false);
 
